@@ -15,7 +15,11 @@
 #include <AppStreamQt/component.h>
 
 #include <QAbstractItemModel>
+#include <QIcon>
 #include <QPixmap>
+
+#include <QCoroTask>
+
 #include <optional>
 
 class AddonList;
@@ -25,8 +29,6 @@ class FlatpakSource;
 class FlatpakResource : public AbstractResource
 {
     Q_OBJECT
-    Q_PROPERTY(QStringList topObjects MEMBER s_topObjects CONSTANT)
-    Q_PROPERTY(QStringList bottomObjects MEMBER s_bottomObjects CONSTANT)
     Q_PROPERTY(QString attentionText READ attentionText CONSTANT)
     Q_PROPERTY(QString dataLocation READ dataLocation CONSTANT)
     Q_PROPERTY(QString branch READ branch CONSTANT)
@@ -86,7 +88,9 @@ public:
         }
     };
 
-    static QString typeAsString(ResourceType type)
+    FlatpakBackend *backend() const;
+
+    static QLatin1String typeAsString(ResourceType type)
     {
         if (type == DesktopApp) {
             return QLatin1String("app");
@@ -106,7 +110,6 @@ public:
     bool canExecute() const override;
     QStringList categories() override;
     QString comment() override;
-    QString commit() const;
     quint64 downloadSize() const;
     QVariant icon() const override;
     QString installedVersion() const override;
@@ -133,7 +136,7 @@ public:
     QString sizeDescription() override;
     AbstractResource::State state() override;
     ResourceType resourceType() const;
-    QString typeAsString() const;
+    QLatin1String typeAsString() const;
     FlatpakResource::Id uniqueId() const;
     QUrl url() const override;
     QDate releaseDate() const override;
@@ -199,15 +202,26 @@ public:
         return m_appdata;
     }
 
-    QString contentRatingText() const override;
     QString contentRatingDescription() const override;
-    ContentIntensity contentRatingIntensity() const override;
     uint contentRatingMinimumAge() const override;
+
+    QStringList topObjects() const override;
+    QStringList bottomObjects() const override;
+
     bool isDesktopApp() const
     {
         return m_type == DesktopApp;
     }
     QString eolReason();
+    void addRefToUpdate(const QByteArray &toUpdate);
+    void clearToUpdate();
+    QVector<QByteArray> toUpdate() const
+    {
+        return m_toUpdate;
+    }
+
+    [[nodiscard]] bool hasResolvedIcon() const override;
+    void resolveIcon() override;
 
 Q_SIGNALS:
     void hasDataChanged();
@@ -215,14 +229,13 @@ Q_SIGNALS:
     void eolReasonChanged();
 
 private:
-    void setCommit(const QString &commit);
+    void setEolReason(const QString &reason);
     void loadPermissions();
 
     const AppStream::Component m_appdata;
     FlatpakResource::Id m_id;
     FlatpakRefKind m_flatpakRefKind;
     QPixmap m_bundledIcon;
-    QString m_commit;
     qint64 m_downloadSize;
     FlatpakFileType m_flatpakFileType = FlatpakResource::NotAFile;
     QString m_flatpakName;
@@ -241,8 +254,12 @@ private:
     QSharedPointer<FlatpakSource> m_temp;
     QVector<FlatpakPermission> m_permissions;
     std::optional<QString> m_eolReason;
+    std::optional<QCoro::Task<>> m_eolReasonTask;
     static const QStringList s_topObjects;
     static const QStringList s_bottomObjects;
+    QVector<QByteArray> m_toUpdate;
+    bool m_stockIcon;
+    std::optional<QIcon> m_icon;
 };
 
 inline uint qHash(const FlatpakResource::Id &key)
