@@ -12,9 +12,9 @@
 #include <AppStreamQt/release.h>
 #include <AppStreamQt/screenshot.h>
 #include <AppStreamQt/version.h>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KService>
+#include <LazyIconResolver.h>
 #include <PackageKit/Daemon>
 #include <QDebug>
 #include <QFile>
@@ -39,14 +39,16 @@ QString AppPackageKitResource::name() const
         if (!m_appdata.extends().isEmpty()) {
             const auto components = backend()->componentsById(m_appdata.extends().constFirst());
 
-            if (components.isEmpty())
+            if (components.isEmpty()) {
                 qWarning() << "couldn't find" << m_appdata.extends() << "which is supposedly extended by" << m_appdata.id();
-            else
+            } else {
                 m_name = components.indexSafe(0)->name() + QLatin1String(" - ") + m_appdata.name();
+            }
         }
 
-        if (m_name.isEmpty())
+        if (m_name.isEmpty()) {
             m_name = m_appdata.name();
+        }
     }
     return m_name;
 }
@@ -54,8 +56,9 @@ QString AppPackageKitResource::name() const
 QString AppPackageKitResource::longDescription()
 {
     const auto desc = m_appdata.description();
-    if (!desc.isEmpty())
+    if (!desc.isEmpty()) {
         return desc;
+    }
 
     return PackageKitResource::longDescription();
 }
@@ -74,7 +77,7 @@ static QIcon componentIcon(const AppStream::Component &comp)
             ret.addFile(icon.url().toLocalFile(), icon.size());
             break;
         case AppStream::Icon::KindStock: {
-            if (KIconLoader::global()->hasIcon(icon.name())) {
+            if (AppStreamUtils::kIconLoaderHasIcon(icon.name())) {
                 return QIcon::fromTheme(icon.name());
             }
             break;
@@ -91,7 +94,12 @@ static QIcon componentIcon(const AppStream::Component &comp)
 
 QVariant AppPackageKitResource::icon() const
 {
-    return componentIcon(m_appdata);
+    if (m_icon.has_value()) {
+        return m_icon.value();
+    }
+
+    LazyIconResolver::instance()->queue(const_cast<AppPackageKitResource *>(this));
+    return u"package-x-generic"_s;
 }
 
 QJsonArray AppPackageKitResource::licenses()
@@ -109,16 +117,18 @@ static constexpr auto s_addonKinds = {AppStream::Component::KindAddon, AppStream
 QStringList AppPackageKitResource::categories()
 {
     auto cats = m_appdata.categories();
-    if (!kContainsValue(s_addonKinds, m_appdata.kind()))
+    if (!kContainsValue(s_addonKinds, m_appdata.kind())) {
         cats.append(QStringLiteral("Application"));
+    }
     return cats;
 }
 
 QString AppPackageKitResource::comment()
 {
     const auto summary = m_appdata.summary();
-    if (!summary.isEmpty())
+    if (!summary.isEmpty()) {
         return summary;
+    }
 
     return PackageKitResource::comment();
 }
@@ -178,7 +188,13 @@ AbstractResource::Type AppPackageKitResource::type() const
 {
     static QString desktop = QString::fromUtf8(qgetenv("XDG_CURRENT_DESKTOP"));
     const auto desktops = m_appdata.compulsoryForDesktops();
-    return kContainsValue(s_addonKinds, m_appdata.kind()) ? Addon : (desktops.isEmpty() || !desktops.contains(desktop)) ? Application : Technical;
+    if (kContainsValue(s_addonKinds, m_appdata.kind())) {
+        return Addon;
+    } else if (desktops.isEmpty() || !desktops.contains(desktop)) {
+        return Application;
+    } else {
+        return System;
+    }
 }
 
 void AppPackageKitResource::fetchScreenshots()
@@ -244,13 +260,8 @@ QString AppPackageKitResource::versionString()
 
 QDate AppPackageKitResource::releaseDate() const
 {
-#if ASQ_CHECK_VERSION(1, 0, 0)
     if (!m_appdata.releasesPlain().isEmpty()) {
         const auto release = m_appdata.releasesPlain().indexSafe(0).value();
-#else
-    if (!m_appdata.releases().isEmpty()) {
-        const auto release = m_appdata.releases().constFirst();
-#endif
         return release.timestamp().date();
     }
 
@@ -283,17 +294,20 @@ QString AppPackageKitResource::contentRatingDescription() const
     return AppStreamUtils::contentRatingDescription(m_appdata);
 }
 
-QString AppPackageKitResource::contentRatingText() const
-{
-    return AppStreamUtils::contentRatingText(m_appdata);
-}
-
-AbstractResource::ContentIntensity AppPackageKitResource::contentRatingIntensity() const
-{
-    return AppStreamUtils::contentRatingIntensity(m_appdata);
-}
-
 uint AppPackageKitResource::contentRatingMinimumAge() const
 {
     return AppStreamUtils::contentRatingMinimumAge(m_appdata);
 }
+
+bool AppPackageKitResource::hasResolvedIcon() const
+{
+    return m_icon.has_value();
+}
+
+void AppPackageKitResource::resolveIcon()
+{
+    m_icon = componentIcon(m_appdata);
+    Q_EMIT iconChanged();
+}
+
+#include "moc_AppPackageKitResource.cpp"
