@@ -121,7 +121,7 @@ public:
     }
     AbstractResource::Type type() const override
     {
-        return Technical;
+        return System;
     }
     bool isRemovable() const override
     {
@@ -633,7 +633,7 @@ void PackageKitUpdater::finished(PackageKit::Transaction::Exit exit, uint /*time
             m_backend->clear();
             setProgressing(false);
         } else {
-            PackageKit::Daemon::global()->offline()->trigger(PackageKit::Offline::ActionReboot);
+            PackageKit::Daemon::global()->offline()->trigger(m_offlineUpdateAction);
         }
         enableReadyToReboot();
     }
@@ -916,5 +916,13 @@ quint64 PackageKitUpdater::downloadSpeed() const
     return m_transaction ? m_transaction->speed() : 0;
 }
 
+void PackageKitUpdater::setOfflineUpdateAction(PackageKit::Offline::Action action)
+{
+    m_offlineUpdateAction = action;
+    if (PackageKit::Daemon::global()->offline()->updateTriggered()) {
+        PackageKit::Daemon::global()->offline()->trigger(action);
+    }
+}
+
 #include "PackageKitUpdater.moc"
 #include "moc_PackageKitUpdater.cpp"
