@@ -6,16 +6,19 @@
 
 #include "SnapResource.h"
 #include "SnapBackend.h"
+#include "libdiscover_snap_debug.h"
+#include <KIO/ApplicationLauncherJob>
+#include <KService>
 #include <KLocalizedString>
 #include <QBuffer>
 #include <QDebug>
+#include <QDBusInterface>
+#include <QFile>
+#include <QFileInfo>
 #include <QImageReader>
 #include <QProcess>
 #include <QStandardItemModel>
-
-#ifdef SNAP_MARKDOWN
 #include <Snapd/MarkdownParser>
-#endif
 
 #include <appstream/AppStreamUtils.h>
 #include <utils.h>
@@ -62,11 +65,9 @@ QDebug operator<<(QDebug debug, const QSnapdSlot *slot)
     return debug;
 }
 
-const QStringList SnapResource::s_topObjects({QStringLiteral("qrc:/qml/PermissionsButton.qml")
-#ifdef SNAP_CHANNELS
-                                                  ,
-                                              QStringLiteral("qrc:/qml/ChannelsButton.qml")
-#endif
+const QStringList SnapResource::s_topObjects({
+    QStringLiteral("qrc:/qml/PermissionsButton.qml"),
+    QStringLiteral("qrc:/qml/ChannelsButton.qml"),
 });
 
 SnapResource::SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::State state, SnapBackend *backend)
@@ -75,6 +76,7 @@ SnapResource::SnapResource(QSharedPointer<QSnapdSnap> snap, AbstractResource::St
     , m_installedSize(0)
     , m_downloadSize(0)
     , m_snap(snap)
+    , m_channel(QStringLiteral("latest/stable"))
 {
     setObjectName(snap->name());
 }
@@ -160,7 +162,6 @@ QJsonArray SnapResource::licenses()
     return AppStreamUtils::licenses(m_snap->license());
 }
 
-#ifdef SNAP_MARKDOWN
 static QString serialize_node(QSnapdMarkdownNode &node);
 
 static QString serialize_children(QSnapdMarkdownNode &node)
@@ -214,20 +215,15 @@ static QString serialize_node(QSnapdMarkdownNode &node)
         return QString();
     }
 }
-#endif
 
 QString SnapResource::longDescription()
 {
-#ifdef SNAP_MARKDOWN
     QSnapdMarkdownParser parser(QSnapdMarkdownParser::MarkdownVersion0);
     QList<QSnapdMarkdownNode> nodes = parser.parse(m_snap->description());
     QString result;
     for (int i = 0; i < nodes.size(); i++)
         result += serialize_node(nodes[i]);
     return result;
-#else
-    return m_snap->description();
-#endif
 }
 
 QString SnapResource::name() const
@@ -272,29 +268,69 @@ void SnapResource::fetchChangelog()
 void SnapResource::fetchScreenshots()
 {
     Screenshots screenshots;
-#ifdef SNAP_MEDIA
     for (int i = 0, c = m_snap->mediaCount(); i < c; ++i) {
         QScopedPointer<QSnapdMedia> media(m_snap->media(i));
         if (media->type() == QLatin1String("screenshot"))
             screenshots << QUrl(media->url());
     }
-#else
-    for (int i = 0, c = m_snap->screenshotCount(); i < c; ++i) {
-        QScopedPointer<QSnapdScreenshot> screenshot(m_snap->screenshot(i));
-        screenshots << QUrl(screenshot->url());
-    }
-#endif
     Q_EMIT screenshotsFetched(screenshots);
 }
 
+QString SnapResource::launchableDesktopFile() const
+{
+    QString desktopFile;
+    qCDebug(LIBDISCOVER_SNAP_LOG) << "Snap: " << packageName() << " - " << m_snap->appCount() << " app(s) detected";
+    for (int i = 0; i < m_snap->appCount(); i++) {
+        const auto appName = m_snap->app(i)->name();
+        const auto appDesktopFile = m_snap->app(i)->desktopFile();
+        if (appDesktopFile.isEmpty()) {
+            qCDebug(LIBDISCOVER_SNAP_LOG) << "App " << i << ": " << appName << ": " << "No desktop file, skipping";
+            continue;
+        }
+        if (packageName().compare(appName, Qt::CaseInsensitive) == 0) {
+            qCDebug(LIBDISCOVER_SNAP_LOG) << "App " << i << ": " << appName << ": " << "Main app, stopping search";
+            desktopFile = appDesktopFile;
+            break;
+        }
+        if (desktopFile.isEmpty()) {
+            qCDebug(LIBDISCOVER_SNAP_LOG) << "App " << i << ": " << appName << ": " << "First candidate, keeping for now";
+            desktopFile = appDesktopFile;
+        }
+    }
+    if (desktopFile.isEmpty()) {
+        qCWarning(LIBDISCOVER_SNAP_LOG) << "No desktop file found for this snap, trying expected name for the main app desktop file";
+        desktopFile = packageName() + QLatin1Char('_') + packageName() + QLatin1StringView(".desktop");
+    }
+    return QFileInfo(desktopFile).fileName();
+}
+
 void SnapResource::invokeApplication() const
 {
-    QProcess::startDetached(QStringLiteral("snap"), {QStringLiteral("run"), packageName()});
+    QDBusInterface interface(
+            QStringLiteral("io.snapcraft.Launcher"),
+            QStringLiteral("/io/snapcraft/PrivilegedDesktopLauncher"),
+            QStringLiteral("io.snapcraft.PrivilegedDesktopLauncher"),
+            QDBusConnection::sessionBus()
+    );
+    interface.call(QStringLiteral("OpenDesktopEntry"), launchableDesktopFile());
 }
 
 AbstractResource::Type SnapResource::type() const
 {
-    return m_snap->snapType() != QSnapdEnums::SnapTypeApp ? Application : Technical;
+    switch (m_snap->snapType()) {
+    case QSnapdEnums::SnapTypeApp:
+        return Application;
+    case QSnapdEnums::SnapTypeCore:
+    case QSnapdEnums::SnapTypeBase:
+        return ApplicationSupport;
+    case QSnapdEnums::SnapTypeGadget:
+    case QSnapdEnums::SnapTypeKernel:
+    case QSnapdEnums::SnapTypeOperatingSystem:
+    case QSnapdEnums::SnapTypeSnapd:
+    case QSnapdEnums::SnapTypeUnknown:
+        return System;
+    }
+    return System;
 }
 
 void SnapResource::setSnap(const QSharedPointer<QSnapdSnap> &snap)
@@ -366,7 +402,7 @@ public:
                     // qDebug() << "xxx" << plug->name() << plug->label() << plug->interface() << slot->snap() << "slot:" << slot->name() <<
                     // slot->snap() << slot->interface() << slot->label();
                     item->setCheckable(true);
-                    item->setCheckState(plug->connectionCount() > 0 ? Qt::Checked : Qt::Unchecked);
+                    item->setCheckState(plug->connectedSlotCount() > 0 ? Qt::Checked : Qt::Unchecked);
                     item->setData(plug->name(), PlugNameRole);
                     item->setData(slot->snap(), SlotSnapRole);
                     item->setData(slot->name(), SlotNameRole);
@@ -421,11 +457,7 @@ QAbstractItemModel *SnapResource::plugs(QObject *p)
 
 QString SnapResource::appstreamId() const
 {
-    const QStringList ids
-#if defined(SNAP_COMMON_IDS)
-        = m_snap->commonIds()
-#endif
-        ;
+    const QStringList ids = m_snap->commonIds();
     return ids.isEmpty() ? QLatin1String("io.snapcraft.") + m_snap->name() + QLatin1Char('-') + m_snap->id() : ids.first();
 }
 
@@ -434,34 +466,32 @@ QStringList SnapResource::topObjects() const
     return s_topObjects;
 }
 
-QString SnapResource::channel() const
+QString SnapResource::channel()
 {
-#ifdef SNAP_PUBLISHER
-    auto req = client()->getSnap(packageName());
-#else
-    auto req = client()->listOne(packageName());
-#endif
-    req->runSync();
-    return req->error() ? QString() : req->snap()->trackingChannel();
+    if (isInstalled()) {
+        auto req = client()->getSnap(packageName());
+        req->runSync();
+        return req->error() ? QString() : req->snap()->trackingChannel();
+    }
+    return m_channel;
 }
 
 QString SnapResource::author() const
 {
-#ifdef SNAP_PUBLISHER
     QString author = m_snap->publisherDisplayName();
     if (m_snap->publisherValidation() == QSnapdEnums::PublisherValidationVerified) {
         author += QStringLiteral(" ✅");
     }
-#else
-    QString author;
-#endif
-
     return author;
 }
 
 void SnapResource::setChannel(const QString &channelName)
 {
-#ifdef SNAP_CHANNELS
+    if (!isInstalled()) {
+        m_channel = channelName;
+        Q_EMIT channelChanged(channelName);
+        return;
+    }
     Q_ASSERT(isInstalled());
     auto request = client()->switchChannel(m_snap->name(), channelName);
 
@@ -473,7 +503,6 @@ void SnapResource::setChannel(const QString &channelName)
             Q_EMIT channelChanged(newChannel);
         }
     });
-#endif
 }
 
 quint64 SnapResource::installedSize() const
@@ -511,7 +540,6 @@ void SnapResource::refreshSnap()
     request->runAsync();
 }
 
-#ifdef SNAP_CHANNELS
 class Channels : public QObject
 {
     Q_OBJECT
@@ -536,10 +564,16 @@ public:
         m_channels.clear();
 
         auto s = m_res->snap();
-        for (int i = 0, c = s->channelCount(); i < c; ++i) {
-            auto channel = s->channel(i);
-            channel->setParent(this);
-            m_channels << channel;
+        const auto risks = { QLatin1StringView("stable"), QLatin1StringView("candidate"), QLatin1StringView("beta"), QLatin1StringView("edge")};
+        QStringList tempChannels;
+        for (auto track : s->tracks()) {
+            for (const auto &risk : risks) {
+                auto channel = s->matchChannel(track + QLatin1Char('/') + risk);
+                if (!tempChannels.contains(channel->name())){
+                    m_channels << channel;
+                    tempChannels << channel->name();
+                }
+            }
         }
         Q_EMIT channelsChanged();
     }
@@ -557,15 +591,9 @@ private:
     SnapResource *const m_res;
 };
 
-#endif
-
 QObject *SnapResource::channels(QObject *parent)
 {
-#ifdef SNAP_CHANNELS
     return new Channels(this, parent);
-#else
-    return nullptr;
-#endif
 }
 
 #include "SnapResource.moc"
