@@ -70,11 +70,14 @@ public:
     }
 
 public Q_SLOTS:
+    void recheckSystemUpdateNeededAndNotifyApp();
     void recheckSystemUpdateNeeded();
     void showDiscover(const QString &xdgActivationToken);
     void showDiscoverUpdates(const QString &xdgActivationToken);
     void showUpdatesNotification();
-    void reboot();
+    void rebootPrompt();
+    void shutdownPrompt();
+    void promptAll();
     void foundUpgradeAction(UpgradeAction *action);
 
 Q_SIGNALS:
@@ -99,5 +102,6 @@ private:
     QPointer<KNotification> m_updatesAvailableNotification;
     UnattendedUpdates *m_unattended = nullptr;
     KConfigWatcher::Ptr m_settingsWatcher;
+    QDateTime m_lastUpdate;
     UpdatesSettings *m_settings;
 };
